[<prev] [next>] [day] [month] [year] [list]
Message-ID: <20241024081515.1cd254a0@canb.auug.org.au>
Date: Thu, 24 Oct 2024 08:15:15 +1100
From: Stephen Rothwell <sfr@...b.auug.org.au>
To: Christian Brauner <brauner@...nel.org>, Chuck Lever
<chuck.lever@...cle.com>
Cc: Benjamin Coddington <bcodding@...hat.com>, Linux Kernel Mailing List
<linux-kernel@...r.kernel.org>, Linux Next Mailing List
<linux-next@...r.kernel.org>, Mike Snitzer <snitzer@...nel.org>
Subject: linux-next: manual merge of the vfs-brauner tree with the nfsd tree
Hi all,
Today's linux-next merge of the vfs-brauner tree got a conflict in:
include/linux/exportfs.h
between commit:
6e99e4b4291e ("nfsd: disallow file locking and delegations for NFSv4 reexport")
from the nfsd tree and commit:
b875bd5b381e ("exportfs: Remove EXPORT_OP_ASYNC_LOCK")
from the vfs-brauner tree.
I fixed it up (see below) and can carry the fix as necessary. This
is now fixed as far as linux-next is concerned, but any non trivial
conflicts should be mentioned to your upstream maintainer when your tree
is submitted for merging. You may also want to consider cooperating
with the maintainer of the conflicting tree to minimise any particularly
complex conflicts.
--
Cheers,
Stephen Rothwell
diff --cc include/linux/exportfs.h
index 106fd590d323,4cc8801e50e3..000000000000
--- a/include/linux/exportfs.h
+++ b/include/linux/exportfs.h
@@@ -251,32 -263,6 +264,19 @@@ struct export_operations
unsigned long flags;
};
- /**
- * exportfs_lock_op_is_async() - export op supports async lock operation
- * @export_ops: the nfs export operations to check
- *
- * Returns true if the nfs export_operations structure has
- * EXPORT_OP_ASYNC_LOCK in their flags set
- */
- static inline bool
- exportfs_lock_op_is_async(const struct export_operations *export_ops)
- {
- return export_ops->flags & EXPORT_OP_ASYNC_LOCK;
- }
-
+/**
+ * exportfs_lock_op_is_unsupported() - export does not support file locking
+ * @export_ops: the nfs export operations to check
+ *
+ * Returns true if the nfs export_operations structure has
+ * EXPORT_OP_NOLOCKSUPPORT in their flags set
+ */
+static inline bool
+exportfs_lock_op_is_unsupported(const struct export_operations *export_ops)
+{
+ return export_ops->flags & EXPORT_OP_NOLOCKSUPPORT;
+}
+
extern int exportfs_encode_inode_fh(struct inode *inode, struct fid *fid,
int *max_len, struct inode *parent,
int flags);
Content of type "application/pgp-signature" skipped
Powered by blists - more mailing lists